@@ -1,11 +1,9 @@
-# $Id: test_chunk.rb 44 2005-05-25 19:51:25Z tilman $
-
 require "eet"
 require "test/unit"
 
 class ChunkTest < Test::Unit::TestCase
 	def setup
-		@data = Eet::Chunk.new("tag", "foo\0bar\0baz").serialize
+		@data = Eet::Chunk.new("tag", "foo\0bar\0baz").to_s
 	end
 
 	def test_serialize
