@@ -1,5 +1,3 @@
-# $Id: test_stream.rb 1 2005-03-26 01:45:38Z tilman $
-
 require "eet"
 require "test/unit"
 
@@ -10,7 +8,7 @@ class StreamTest < Test::Unit::TestCase
 		stream << Eet::Chunk.new("tag2", "bar")
 		stream << Eet::Chunk.new("tag23", "baz")
 
-		@data = stream.serialize
+		@data = stream.to_s
 		assert_not_nil(@data)
 	end
 
